#include <qthing.h>

#include "freertos/FreeRTOS.h"
#include "freertos/task.h"

#include "driver/gpio.h"

#include "mqtt_common.h"
#include "esp_log.h"


#include "IRSender.hpp"

#include "Arduino.h"


// #######################
// ####### CONFIG ########
// #######################

const uint8_t senderTX = 26;
const uint8_t senderCLK = 25;

const uint8_t receiverRX = 23;

// ### end cfg ###


HardwareSerial sender(1);
HardwareSerial receiver(2);


void senderTask(void *ignored) {

  uint16_t delay = 10;
  vTaskDelay(delay / portTICK_PERIOD_MS);

  while (true) {
    sender.print("Hello, Infrared communication!");
    vTaskDelay(delay / portTICK_PERIOD_MS);

    sender.print(" typing…");
    vTaskDelay(delay / portTICK_PERIOD_MS);

    sender.print(" 🐾…");
    vTaskDelay(delay / portTICK_PERIOD_MS);

    sender.println(" 🕷🕸😏");
    vTaskDelay(delay / portTICK_PERIOD_MS);
  }
}


void receiverTask(void *ignored) {
  while (true) {
    if (receiver.available())
      Serial.print( (char)receiver.read() );
    else
      vTaskDelay(2);
  }
}


void device_main() {

  // enable_wlan();


  IRSender(senderTX, senderCLK);
  // TODO: configure UART in IRSender!

  Serial.begin(115200);

  uint16_t baud = 4800;

  sender.begin(baud, SERIAL_8N1, -1, senderTX);  // tx = 27
  receiver.begin(baud, SERIAL_8N1, receiverRX, -1);  // rx = 26

  xTaskCreate(senderTask, "sender", 8192, NULL, 6, NULL);
  xTaskCreate(receiverTask, "receiver", 8192, NULL, 6, NULL);
}
